# (c) 2007 by Ralf Ertzinger <ralf@camperquake.de>
# licensed under GNU GPL v2
#
# Grabber for german-bash.org

package quotesite::iBashGrabber;

use quotesite::GrabberBase;
@ISA = qw(quotesite::GrabberBase);

use LWP::Simple qw(!get);
use HTML::TokeParser;
use Data::Dumper;
use Encode;

use strict;

sub new {
    my $class = shift;
    my $self = $class->SUPER::new();

    $self->{'NAME'} = 'ibash.de';
    $self->{'PATTERNS'} = ['(http://(?:[-a-zA-Z0-9_.]+\.)*ibash.de/zitat_(\d+)\.html)'];

    bless($self, $class);
    $self->_prepare_parameters();

    return $self;
}

sub __buildquote_line {
    my $self = shift;
    my $p = shift;
    my $t;
    my $data = '';

    while ($t = $p->get_tag('td', '/tr')) {
        if ($t->[0] eq '/tr') {
            return $data;
        }
        if (exists($t->[1]->{'colspan'})) {
            return '';
        }
        $data .= $p->get_text('/td')
    }
}


sub __buildquote_block {
    my $self = shift;
    my $p = shift;
    my $t;
    my $data;

    while ($t = $p->get_tag('tr','/table')) {
        if ($t->[0] eq '/table') {
            return $data;
        }
        $data .= $self->__buildquote_line($p) . "\n";
    }
}

sub _parse {
    my $self = shift;
    my $url = shift;
    my $pattern = shift;
    my $content;
    my $metadata = {};
    my $p;
    my $t;

    $url =~ m|$pattern|;
    $url = $1;

    $metadata->{'URL'} = $url;
    $metadata->{'ID'} = $2;
    $metadata->{'TYPE'} = 'quote';
    $metadata->{'SOURCE'} = $self->{'NAME'};
    $metadata->{'CONTENT'} = undef;

    # Get the HTML file containing the quote
    unless(defined($content = LWP::Simple::get(sprintf('http://www.ibash.de/zitat_%s.html', $2)))) {
        $self->error('Could not download quote');
        return undef;
    }

    $p = HTML::TokeParser->new(\$content);

    while ($t = $p->get_tag('td')) {
        if (exists($t->[1]->{'class'}) && ($t->[1]->{'class'} eq 'quote')) {
            $metadata->{'CONTENT'} = $self->__buildquote_block($p);
            Encode::from_to($metadata->{'CONTENT'}, 'iso-8859-1', 'utf8');
        }
    }

    unless(defined($metadata->{'CONTENT'})) {
        $self->error('Could not extract quote content');
        return undef;
    }

    return $metadata;
}

1;
